==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 */
$lang['menu']                  = 'Ylläpidä liitännäisiä';
$lang['download']              = 'Lataa ja asenna uusi liitännäinen';
$lang['manage']                = 'Asennetut liitännäiset';
$lang['btn_info']              = 'tietoa';
$lang['btn_update']            = 'päivitä';
$lang['btn_delete']            = 'poista';
$lang['btn_settings']          = 'asetukset';
$lang['btn_download']          = 'Lataa';
$lang['btn_enable']            = 'Tallenna';
$lang['url']                   = 'URL';
$lang['installed']             = 'Asennettu:';
$lang['lastupdate']            = 'Päivitetty viimeksi:';
$lang['source']                = 'Lähde:';
$lang['unknown']               = 'tuntematon';
$lang['updating']              = 'Päivitetään ...';
$lang['updated']               = 'Liitännäinen %s päivitetty onnistuneesti';
$lang['updates']               = 'Seuraavat liitännäiset on päivitetty onnistuneesti';
$lang['update_none']           = 'Päivityksiä ei löytynyt';
$lang['deleting']              = 'Poistetaan ...';
$lang['deleted']               = 'Liitännäinen %s poistettu.';
$lang['downloading']           = 'Ladataan ...';
$lang['downloaded']            = 'Liitännäinen %s asennettu onnistuneesti';
$lang['downloads']             = 'Seuraavat liitännäiset on asennettu onnistuneesti';
$lang['download_none']         = 'Liitännäisiä ei löytynyt tai on tapahtunut joku tuntematon virhe latauksen ja asennuksen aikana.';
$lang['plugin']                = 'Liitännäinen:';
$lang['components']            = 'Osa';
$lang['noinfo']                = 'Liitännäinen ei palauttanut mitään tietoa ja se voi olla epäkelpo.';
$lang['name']                  = 'Nimi:';
$lang['date']                  = 'Päiväys:';
$lang['type']                  = 'Tyyppi:';
$lang['desc']                  = 'Kuvaus:';
$lang['author']                = 'Tekijä:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Tapahtui tuntematon virhe.';
$lang['error_download']        = 'Liitännäistiedoston %s latauksessa tapahtui tuntematon virhe.';
$lang['error_badurl']          = 'Url näyttää olleen väärä. Ei pystytty päättelemään tiedoston nimeä siitä.';
$lang['error_dircreate']       = 'Ei pystytty luomaan väliaikaista hakemistoa latausta varten';
$lang['error_decompress']      = 'Liitännäishallinta ei pystynyt purkamaan ladattua tiedostoa. Lataus voi olla epäonnistunut. Siinä tapauksessa voit yrittää uudestaan. Pakkaustapa voi myös olla tuntematon. Siinä tapauksessa sinun pitää ladata ja asentaa liitännäinen käsin.';
$lang['error_copy']            = 'Tiedoston kopioinnissa tapahtui liitännäisen <em>%s</em> asennuksen aikana virhe. Levy voi olla täynnä tai kansioiden oikeudet voivat olla väärin. Liitännäinen voi olla osittain asennettu ja tämä voi jättää wikiasennukseesi epävakaaseen tilaan.';
$lang['error_delete']          = 'Liitännäisen <em>%s</em> poistossa tapahtui virhe. Todennäköisin syy on puutteelliset tiedoston tai hakemiston oikeudet';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 * @author Otto Vainio <otto@valjakko.net>
 */
$lang['menu']                  = 'Ylläpidä liitännäisiä';
$lang['download']              = 'Lataa ja asenna uusi liitännäinen';
$lang['manage']                = 'Asennetut liitännäiset';
$lang['btn_info']              = 'tietoa';
$lang['btn_update']            = 'päivitä';
$lang['btn_delete']            = 'poista';
$lang['btn_settings']          = 'asetukset';
$lang['btn_download']          = 'Lataa';
$lang['btn_enable']            = 'Tallenna';
$lang['url']                   = 'URL';
$lang['installed']             = 'Asennettu:';
$lang['lastupdate']            = 'Päivitetty viimeksi:';
$lang['source']                = 'Lähde:';
$lang['unknown']               = 'tuntematon';
$lang['updating']              = 'Päivitetään ...';
$lang['updated']               = 'Liitännäinen %s päivitetty onnistuneesti';
$lang['updates']               = 'Seuraavat liitännäiset on päivitetty onnistuneesti';
$lang['update_none']           = 'Päivityksiä ei löytynyt';
$lang['deleting']              = 'Poistetaan ...';
$lang['deleted']               = 'Liitännäinen %s poistettu.';
$lang['downloading']           = 'Ladataan ...';
$lang['downloaded']            = 'Liitännäinen %s asennettu onnistuneesti';
$lang['downloads']             = 'Seuraavat liitännäiset on asennettu onnistuneesti';
$lang['download_none']         = 'Liitännäisiä ei löytynyt tai on tapahtunut joku tuntematon virhe latauksen ja asennuksen aikana.';
$lang['plugin']                = 'Liitännäinen:';
$lang['components']            = 'Osa';
$lang['noinfo']                = 'Liitännäinen ei palauttanut mitään tietoa ja se voi olla epäkelpo.';
$lang['name']                  = 'Nimi:';
$lang['date']                  = 'Päiväys:';
$lang['type']                  = 'Tyyppi:';
$lang['desc']                  = 'Kuvaus:';
$lang['author']                = 'Tekijä:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Tapahtui tuntematon virhe.';
$lang['error_download']        = 'Liitännäistiedoston %s latauksessa tapahtui tuntematon virhe.';
$lang['error_badurl']          = 'Url näyttää olleen väärä. Ei pystytty päättelemään tiedoston nimeä siitä.';
$lang['error_dircreate']       = 'Ei pystytty luomaan väliaikaista hakemistoa latausta varten';
$lang['error_decompress']      = 'Liitännäishallinta ei pystynyt purkamaan ladattua tiedostoa. Lataus voi olla epäonnistunut. Siinä tapauksessa voit yrittää uudestaan. Pakkaustapa voi myös olla tuntematon. Siinä tapauksessa sinun pitää ladata ja asentaa liitännäinen käsin.';
$lang['error_copy']            = 'Tiedoston kopioinnissa tapahtui liitännäisen <em>%s</em> asennuksen aikana virhe. Levy voi olla täynnä tai kansioiden oikeudet voivat olla väärin. Liitännäinen voi olla osittain asennettu ja tämä voi jättää wikiasennukseesi epävakaaseen tilaan.';
$lang['error_delete']          = 'Liitännäisen <em>%s</em> poistossa tapahtui virhe. Todennäköisin syy on puutteelliset tiedoston tai hakemiston oikeudet';
$lang['enabled']               = 'Liitännäinen %s käytössä';
$lang['notenabled']            = 'Liitännäistä %s ei voitu ottaa käyttöön. Tarkista tiedostojen oikeudet.';
$lang['disabled']              = 'Liitännäinen %s pois käytössä';
$lang['notdisabled']           = 'Liitännäistä %s ei voitu ottaa pois käytöstä. Tarkista tiedostojen oikeudet.';
